@@ -32,17 +32,20 @@ elif operating_system.startswith('cygwin'):
     JVM_INCPATH = ['-I"/cygdrive/c/Program Files/Java/jdk1.7.0_17/include"', '-I"/cygdrive/c/Program Files/Java/jdk1.7.0_17/include/win32"']
     JVM_LIBPATH = ['-L"/cygdrive/c/Program Files/Java/jdk1.7.0_17/jre/bin/server"']
 else:
-    known_jvms = ('/usr/lib/jvm/java-7-openjdk', '/usr/local/openjdk7', '/usr/lib/jvm/java-6-openjdk', '/usr/local/openjdk', '/usr/java', '/usr/lib/jvm/java/', '/usr/lib/jvm/java-8-openjdk-%s' % arch)
+    known_jvms = ('/usr/lib/jvm/java-7-openjdk', '/usr/local/openjdk7', '/usr/lib/jvm/java-6-openjdk', '/usr/local/openjdk', '/usr/java', '/usr/lib/jvm/java/', '/usr/lib/jvm/java-8-openjdk-%s' % arch, '/usr/lib/jvm/java-11-openjdk-%s' % arch)
     for jvm in known_jvms:
-       if os.path.exists(jvm + '/include'):
-           JVM_INCPATH = ["-I%s/include/" % jvm, "-I%s/include/%s" % (jvm, operating_system)]
-           JVM_LIBPATH = ["-L%s/jre/lib/%s/server" % (jvm, arch)]
-           break
-       if os.path.exists("%s-%s/include" % (jvm, arch)):
-           jvm = "%s-%s" % (jvm, arch)
-           JVM_INCPATH = ["-I%s/include/" % jvm, "-I%s/include/%s" % (jvm, operating_system)]
-           JVM_LIBPATH = ["-L%s/jre/lib/%s/server" % (jvm, arch)]
-           break
+        if os.path.exists(jvm + '/include'):
+            JVM_INCPATH = ["-I%s/include/" % jvm, "-I%s/include/%s" % (jvm, operating_system)]
+            if os.path.exists("%s/jre"):
+                JVM_LIBPATH = ["-L%s/jre/lib/%s/server" % (jvm, arch)]
+            else:
+                JVM_LIBPATH = ["-L%s/lib/server" % (jvm,)]
+            break
+        if os.path.exists("%s-%s/include" % (jvm, arch)):
+            jvm = "%s-%s" % (jvm, arch)
+            JVM_INCPATH = ["-I%s/include/" % jvm, "-I%s/include/%s" % (jvm, operating_system)]
+            JVM_LIBPATH = ["-L%s/jre/lib/%s/server" % (jvm, arch)]
+            break
 
 try:
     JVM_INCPATH = ['-I"' + os.environ['UWSGICONFIG_JVM_INCPATH'] + '"']
